@@ -15,7 +15,7 @@ import re
 from pypck import lcn_defs
 
 
-class PckParser():
+class PckParser:
     """Helpers to parse LCN-PCK commands.
 
     LCN-PCK is the command-syntax used by LCN-PCHK to send and receive LCN
@@ -23,97 +23,118 @@ class PckParser():
     """
 
     # Authentication at LCN-PCHK: Request user name.
-    AUTH_USERNAME = 'Username:'
+    AUTH_USERNAME = "Username:"
 
     # Authentication at LCN-PCHK: Request password.
-    AUTH_PASSWORD = 'Password:'
+    AUTH_PASSWORD = "Password:"
 
     # Authentication at LCN-PCHK succeeded.
-    AUTH_OK = 'OK'
+    AUTH_OK = "OK"
+
+    # Authentication at LCN-PCHK failed.
+    AUTH_FAILED = "Authentification failed."
 
     # LCN-PK/PKU is connected.
-    LCNCONNSTATE_CONNECTED = '$io:#LCN:connected'
+    LCNCONNSTATE_CONNECTED = "$io:#LCN:connected"
 
     # LCN-PK/PKU is disconnected.
-    LCNCONNSTATE_DISCONNECTED = '$io:#LCN:disconnected'
+    LCNCONNSTATE_DISCONNECTED = "$io:#LCN:disconnected"
+
+    # License Error
+    LICENSE_ERROR = "$err:(license?)"
 
     # Pattern to parse error messages.
-    PATTERN_COMMAND_ERROR = re.compile(
-        r'\((?P<message>.+)\?\)')
+    PATTERN_COMMAND_ERROR = re.compile(r"\((?P<message>.+)\?\)")
 
     # Pattern to parse positive acknowledges.
-    PATTERN_ACK_POS = re.compile(
-        r'-M(?P<seg_id>\d{3})(?P<mod_id>\d{3})!')
+    PATTERN_ACK_POS = re.compile(r"-M(?P<seg_id>\d{3})(?P<mod_id>\d{3})!")
 
     # Pattern to parse negative acknowledges.
-    PATTERN_ACK_NEG = re.compile(
-        r'-M(?P<seg_id>\d{3})(?P<mod_id>\d{3})(?P<code>\d+)')
+    PATTERN_ACK_NEG = re.compile(r"-M(?P<seg_id>\d{3})(?P<mod_id>\d{3})(?P<code>\d+)")
 
     # Pattern to parse segment coupler responses.
     PATTERN_SK_RESPONSE = re.compile(
-        r'=M(?P<seg_id>\d{3})(?P<mod_id>\d{3})\.SK(?P<id>\d+)')
+        r"=M(?P<seg_id>\d{3})(?P<mod_id>\d{3})\.SK(?P<id>\d+)"
+    )
 
     # Pattern to parse serial number and firmware date responses.
     PATTERN_SN = re.compile(
-        r'=M(?P<seg_id>\d{3})(?P<mod_id>\d{3}).SN(?P<sn>[0-9|A-F]{10})'
-        r'(?P<manu>[0-9|A-F]{2})FW(?P<sw_age>[0-9|A-F]{6})HW(?P<hw_type>\d+)')
+        r"=M(?P<seg_id>\d{3})(?P<mod_id>\d{3}).SN(?P<sn>[0-9|A-F]{10})"
+        r"(?P<manu>[0-9|A-F]{2})FW(?P<sw_age>[0-9|A-F]{6})HW(?P<hw_type>\d+)"
+    )
+
+    # Pattern to parse module name and comment
+    PATTERN_NAME_COMMENT = re.compile(
+        r"=M(?P<seg_id>\d{3})(?P<mod_id>\d{3}).(?P<command>[NKO])"
+        r"(?P<block_id>\d)(?P<text>.{0,12})"
+    )
 
     # Pattern to parse output-port status responses in percent.
     PATTERN_STATUS_OUTPUT_PERCENT = re.compile(
-        r':M(?P<seg_id>\d{3})(?P<mod_id>\d{3})A(?P<output_id>\d)'
-        r'(?P<percent>\d+)')
+        r":M(?P<seg_id>\d{3})(?P<mod_id>\d{3})A(?P<output_id>\d)" r"(?P<percent>\d+)"
+    )
 
     # Pattern to parse output-port status responses in native format (0..200).
     PATTERN_STATUS_OUTPUT_NATIVE = re.compile(
-        r':M(?P<seg_id>\d{3})(?P<mod_id>\d{3})O(?P<output_id>\d)'
-        r'(?P<value>\d+)')
+        r":M(?P<seg_id>\d{3})(?P<mod_id>\d{3})O(?P<output_id>\d)" r"(?P<value>\d+)"
+    )
 
     # Pattern to parse relays status responses.
     PATTERN_STATUS_RELAYS = re.compile(
-        r':M(?P<seg_id>\d{3})(?P<mod_id>\d{3})Rx(?P<byte_value>\d+)')
+        r":M(?P<seg_id>\d{3})(?P<mod_id>\d{3})Rx(?P<byte_value>\d+)"
+    )
 
     # Pattern to parse binary-sensors status responses.
     PATTERN_STATUS_BINSENSORS = re.compile(
-        r':M(?P<seg_id>\d{3})(?P<mod_id>\d{3})Bx(?P<byte_value>\d+)')
+        r":M(?P<seg_id>\d{3})(?P<mod_id>\d{3})Bx(?P<byte_value>\d+)"
+    )
 
     # Pattern to parse variable 1-12 status responses (since 170206).
     PATTERN_STATUS_VAR = re.compile(
-        r'%M(?P<seg_id>\d{3})(?P<mod_id>\d{3})\.A(?P<id>\d{3})(?P<value>\d+)')
+        r"%M(?P<seg_id>\d{3})(?P<mod_id>\d{3})\.A(?P<id>\d{3})(?P<value>\d+)"
+    )
 
     # Pattern to parse set-point variable status responses (since 170206).
     PATTERN_STATUS_SETVAR = re.compile(
-        r'%M(?P<seg_id>\d{3})(?P<mod_id>\d{3})\.S(?P<id>\d)(?P<value>\d+)')
+        r"%M(?P<seg_id>\d{3})(?P<mod_id>\d{3})\.S(?P<id>\d)(?P<value>\d+)"
+    )
 
     # Pattern to parse threshold status responses (since 170206).
     PATTERN_STATUS_THRS = re.compile(
-        r'%M(?P<seg_id>\d{3})(?P<mod_id>\d{3})\.T(?P<register_id>\d)'
-        r'(?P<thrs_id>\d)(?P<value>\d+)')
+        r"%M(?P<seg_id>\d{3})(?P<mod_id>\d{3})\.T(?P<register_id>\d)"
+        r"(?P<thrs_id>\d)(?P<value>\d+)"
+    )
 
     # Pattern to parse S0-input status responses (LCN-BU4L).
     PATTERN_STATUS_S0INPUT = re.compile(
-        r'%M(?P<seg_id>\d{3})(?P<mod_id>\d{3})\.C(?P<id>\d)(?P<value>\d+)')
+        r"%M(?P<seg_id>\d{3})(?P<mod_id>\d{3})\.C(?P<id>\d)(?P<value>\d+)"
+    )
 
     # Pattern to parse generic variable status responses (concrete type
     # unknown, before 170206).
     PATTERN_VAR_GENERIC = re.compile(
-        r'%M(?P<seg_id>\d{3})(?P<mod_id>\d{3})\.(?P<value>\d+)')
+        r"%M(?P<seg_id>\d{3})(?P<mod_id>\d{3})\.(?P<value>\d+)"
+    )
 
     # Pattern to parse threshold register 1 status responses (5 values,
     # before 170206). */
     PATTERN_THRS5 = re.compile(
-        r'=M(?P<seg_id>\d{3})(?P<mod_id>\d{3})\.S1(?P<value1>\d{5})'
-        r'(?P<value2>\d{5})(?P<value3>\d{5})(?P<value4>\d{5})'
-        r'(?P<value5>\d{5})(?P<hyst>\d{5})')
+        r"=M(?P<seg_id>\d{3})(?P<mod_id>\d{3})\.S1(?P<value1>\d{5})"
+        r"(?P<value2>\d{5})(?P<value3>\d{5})(?P<value4>\d{5})"
+        r"(?P<value5>\d{5})(?P<hyst>\d{5})"
+    )
 
     # Pattern to parse status of LEDs and logic-operations responses.
     PATTERN_STATUS_LEDSANDLOGICOPS = re.compile(
-        r'=M(?P<seg_id>\d{3})(?P<mod_id>\d{3})\.TL(?P<led_states>[AEBF]{12})'
-        r'(?P<logic_op_states>[NTV]{4})')
+        r"=M(?P<seg_id>\d{3})(?P<mod_id>\d{3})\.TL(?P<led_states>[AEBF]{12})"
+        r"(?P<logic_op_states>[NTV]{4})"
+    )
 
     # Pattern to parse key-locks status responses.
     PATTERN_STATUS_KEYLOCKS = re.compile(
-        r'=M(?P<seg_id>\d{3})(?P<mod_id>\d{3})\.TX(?P<table0>\d{3})'
-        r'(?P<table1>\d{3})(?P<table2>\d{3})((?P<table3>\d{3}))?')
+        r"=M(?P<seg_id>\d{3})(?P<mod_id>\d{3})\.TX(?P<table0>\d{3})"
+        r"(?P<table1>\d{3})(?P<table2>\d{3})((?P<table3>\d{3}))?"
+    )
 
     @staticmethod
     def get_boolean_value(input_byte):
@@ -125,7 +146,7 @@ class PckParser():
         :rtype:     list
         """
         if (input_byte < 0) or (input_byte > 255):
-            raise ValueError('Invalid input_byte.')
+            raise ValueError("Invalid input_byte.")
 
         result = []
         for i in range(8):
@@ -133,7 +154,7 @@ class PckParser():
         return result
 
 
-class PckGenerator():
+class PckGenerator:
     """Helpers to generate LCN-PCK commands.
 
     LCN-PCK is the command-syntax used by LCN-PCHK to send and receive LCN
@@ -141,9 +162,9 @@ class PckGenerator():
     """
 
     # Terminates a PCK command
-    TERMINATION = '\n'
+    TERMINATION = "\n"
 
-    TABLE_NAMES = ['A', 'B', 'C', 'D']
+    TABLE_NAMES = ["A", "B", "C", "D"]
 
     @staticmethod
     def ping(counter):
@@ -158,7 +179,7 @@ class PckGenerator():
         :return:    The PCK command as text
         :rtype:    str
         """
-        return '^ping{:d}'.format(counter)
+        return "^ping{:d}".format(counter)
 
     @staticmethod
     def set_operation_mode(dim_mode, status_mode):
@@ -174,11 +195,10 @@ class PckGenerator():
         :return:    The PCK command as text
         :rtype:    str
         """
-        return '!OM{:s}{:s}'.format(
-            '1' if (dim_mode == lcn_defs.OutputPortDimMode.STEPS200)
-            else '0',
-            'P' if (status_mode == lcn_defs.OutputPortStatusMode.PERCENT)
-            else 'N')
+        return "!OM{:s}{:s}".format(
+            "1" if (dim_mode == lcn_defs.OutputPortDimMode.STEPS200) else "0",
+            "P" if (status_mode == lcn_defs.OutputPortStatusMode.PERCENT) else "N",
+        )
 
     @staticmethod
     def generate_address_header(addr, local_seg_id, wants_ack):
@@ -192,11 +212,12 @@ class PckGenerator():
         :return:    The PCK address header string.
         :rtype:     str
         """
-        return '>{:s}{:03d}{:03d}{:s}'.format('G' if addr.is_group() else 'M',
-                                              addr.get_physical_seg_id(
-                                                  local_seg_id),
-                                              addr.get_id(),
-                                              '!' if wants_ack else '.')
+        return ">{:s}{:03d}{:03d}{:s}".format(
+            "G" if addr.is_group() else "M",
+            addr.get_physical_seg_id(local_seg_id),
+            addr.get_id(),
+            "!" if wants_ack else ".",
+        )
 
     @staticmethod
     def segment_coupler_scan():
@@ -208,7 +229,7 @@ class PckGenerator():
         :return:    The PCK command (without address header) as text
         :rtype:    str
         """
-        return 'SK'
+        return "SK"
 
     @staticmethod
     def request_serial():
@@ -217,7 +238,40 @@ class PckGenerator():
         :return: The PCK command (without address header) as text
         :rtype:    str
         """
-        return 'SN'
+        return "SN"
+
+    @staticmethod
+    def request_name(block_id):
+        """ Generate a name request.
+
+        :return The PCK command (without address header) as text
+        :rtype:    str
+        """
+        if block_id not in [0, 1]:
+            raise ValueError("Invalid block_id.")
+        return "NMN{:d}".format(block_id + 1)
+
+    @staticmethod
+    def request_comment(block_id):
+        """ Generate a comment request.
+
+        :return The PCK command (without address header) as text
+        :rtype:    str
+        """
+        if block_id not in [0, 1, 2]:
+            raise ValueError("Invalid block_id.")
+        return "NMK{:d}".format(block_id + 1)
+
+    @staticmethod
+    def request_oem_text(block_id):
+        """ Generate an oem text request.
+
+        :return The PCK command (without address header) as text
+        :rtype:    str
+        """
+        if block_id not in [0, 1, 2, 3]:
+            raise ValueError("Invalid block_id.")
+        return "NMO{:d}".format(block_id + 1)
 
     @staticmethod
     def request_output_status(output_id):
@@ -228,8 +282,8 @@ class PckGenerator():
         :rtype:    str
         """
         if (output_id < 0) or (output_id > 3):
-            raise ValueError('Invalid output_id.')
-        return 'SMA{:d}'.format(output_id + 1)
+            raise ValueError("Invalid output_id.")
+        return "SMA{:d}".format(output_id + 1)
 
     @staticmethod
     def dim_ouput(output_id, percent, ramp):
@@ -242,18 +296,16 @@ class PckGenerator():
         :rtype:    str
         """
         if (output_id < 0) or (output_id > 3):
-            raise ValueError('Invalid output_id.')
+            raise ValueError("Invalid output_id.")
         percent_round = int(round(percent * 2))
         ramp = int(ramp)
         if (percent_round % 2) == 0:
             # Use the percent command (supported by all LCN-PCHK versions)
-            pck = 'A{:d}DI{:03d}{:03d}'.format(output_id + 1,
-                                               percent_round // 2, ramp)
+            pck = "A{:d}DI{:03d}{:03d}".format(output_id + 1, percent_round // 2, ramp)
         else:
             # We have a ".5" value. Use the native command (supported since
             # LCN-PCHK 2.3)
-            pck = 'O{:d}DI{:03d}{:03d}'.format(output_id + 1,
-                                               percent_round, ramp)
+            pck = "O{:d}DI{:03d}{:03d}".format(output_id + 1, percent_round, ramp)
         return pck
 
     @staticmethod
@@ -270,15 +322,14 @@ class PckGenerator():
         percent_round = round(percent * 2)
         if is1805:
             # Supported since LCN-PCHK 2.61
-            pck = 'OY{0:03d}{0:03d}{0:03d}{0:03d}{1:03d}'.format(
-                percent_round, ramp)
+            pck = "OY{0:03d}{0:03d}{0:03d}{0:03d}{1:03d}".format(percent_round, ramp)
         elif percent_round == 0:  # All off
-            pck = 'AA{:03d}'.format(ramp)
+            pck = "AA{:03d}".format(ramp)
         elif percent_round == 200:  # All on
-            pck = 'AE{:03d}'.format(ramp)
+            pck = "AE{:03d}".format(ramp)
         else:
             # This is our worst-case: No high-res, no ramp
-            pck = 'AH{:03d}'.format(percent_round / 2)
+            pck = "AH{:03d}".format(percent_round / 2)
         return pck
 
     @staticmethod
@@ -291,22 +342,20 @@ class PckGenerator():
         :rtype:    str
         """
         if (output_id < 0) or (output_id > 3):
-            raise ValueError('Invalid output_id.')
+            raise ValueError("Invalid output_id.")
 
         percent_round = round(percent * 2)
         if percent_round % 2 == 0:
             # Use the percent command (supported by all LCN-PCHK versions)
-            pck = 'A{:d}{:s}{:03d}'.format(output_id + 1, 'AD'
-                                           if percent >= 0
-                                           else 'SB',
-                                           abs(percent_round // 2))
+            pck = "A{:d}{:s}{:03d}".format(
+                output_id + 1, "AD" if percent >= 0 else "SB", abs(percent_round // 2)
+            )
         else:
             # We have a ".5" value. Use the native command (supported since
             # LCN-PCHK 2.3)
-            pck = 'O{:d}{:s}{:03d}'.format(output_id + 1, 'AD'
-                                           if percent >= 0
-                                           else 'SB',
-                                           abs(percent_round))
+            pck = "O{:d}{:s}{:03d}".format(
+                output_id + 1, "AD" if percent >= 0 else "SB", abs(percent_round)
+            )
             return pck
 
     @staticmethod
@@ -321,8 +370,8 @@ class PckGenerator():
         :rtype:    str
         """
         if (output_id < 0) or (output_id > 3):
-            raise ValueError('Invalid output_id.')
-        return 'A{:d}TA{:03d}'.format(output_id + 1, ramp)
+            raise ValueError("Invalid output_id.")
+        return "A{:d}TA{:03d}".format(output_id + 1, ramp)
 
     @staticmethod
     def toggle_all_outputs(ramp):
@@ -334,7 +383,7 @@ class PckGenerator():
         :return:    The PCK command (without address header) as text
         :rtype:    str
         """
-        return 'AU{:03d}'.format(ramp)
+        return "AU{:03d}".format(ramp)
 
     @staticmethod
     def request_relays_status():
@@ -343,7 +392,7 @@ class PckGenerator():
         :return: The PCK command (without address header) as text
         :rtype:    str
         """
-        return 'SMR'
+        return "SMR"
 
     @staticmethod
     def control_relays(states):
@@ -355,8 +404,8 @@ class PckGenerator():
         :rtype:    str
         """
         if len(states) != 8:
-            raise ValueError('Invalid states length.')
-        ret = 'R8'
+            raise ValueError("Invalid states length.")
+        ret = "R8"
         for state in states:
             ret += state.value
 
@@ -372,8 +421,8 @@ class PckGenerator():
         :rtype:   str
         """
         if len(states) != 4:
-            raise ValueError('Invalid states length.')
-        ret = 'R8'
+            raise ValueError("Invalid states length.")
+        ret = "R8"
         for state in states:
             if state == lcn_defs.MotorStateModifier.UP:
                 ret += lcn_defs.RelayStateModifier.ON.value
@@ -418,8 +467,8 @@ class PckGenerator():
             elif reverse_time == lcn_defs.MotorReverseTime.RT1200:
                 params = (0x04, 0xC8, 0x0B)
             else:
-                raise ValueError('Wrong MotorReverseTime.')
-            ret = 'X2{:03d}{:03d}{:03d}'.format(*params)
+                raise ValueError("Wrong MotorReverseTime.")
+            ret = "X2{:03d}{:03d}{:03d}".format(*params)
 
         elif state == lcn_defs.MotorStateModifier.DOWN:
             if reverse_time in [None, lcn_defs.MotorReverseTime.RT70]:
@@ -429,16 +478,15 @@ class PckGenerator():
             elif reverse_time == lcn_defs.MotorReverseTime.RT1200:
                 params = (0x05, 0xC8, 0x0B)
             else:
-                raise ValueError('Wrong MotorReverseTime.')
-            ret = 'X2{:03d}{:03d}{:03d}'.format(*params)
+                raise ValueError("Wrong MotorReverseTime.")
+            ret = "X2{:03d}{:03d}{:03d}".format(*params)
 
         elif state == lcn_defs.MotorStateModifier.STOP:
-            ret = 'AY000000'
+            ret = "AY000000"
         elif state == lcn_defs.MotorStateModifier.CYCLE:
-            ret = 'JE'
+            ret = "JE"
         else:
-            raise ValueError(
-                'MotorStateModifier is not supported by output ports.')
+            raise ValueError("MotorStateModifier is not supported by output ports.")
 
         return ret
 
@@ -449,7 +497,7 @@ class PckGenerator():
         :return:    The PCK command (without address header) as text
         :rtype:    str
         """
-        return 'SMB'
+        return "SMB"
 
     @staticmethod
     def var_abs(var, value):
@@ -466,13 +514,13 @@ class PckGenerator():
             byte1 = set_point_id << 6  # 01000000
             byte1 |= 0x20  # xx10xxxx (set absolute)
             value -= 1000  # Offset
-            byte1 |= (value >> 8) & 0x0f  # xxxx1111
-            byte2 = value & 0xff
-            return 'X2{:03d}{:03d}{:03d}'.format(30, byte1, byte2)
+            byte1 |= (value >> 8) & 0x0F  # xxxx1111
+            byte2 = value & 0xFF
+            return "X2{:03d}{:03d}{:03d}".format(30, byte1, byte2)
 
         # Setting variables and thresholds absolute not implemented in LCN
         # firmware yet
-        raise ValueError('Wrong variable type.')
+        raise ValueError("Wrong variable type.")
 
     @staticmethod
     def update_status_var(var, value):
@@ -490,13 +538,13 @@ class PckGenerator():
         if var_id != -1:
             # define variable to set, offset 0x01000000
             x2cmd = var_id | 0x40
-            byte1 = (value >> 8) & 0xff
-            byte2 = value & 0xff
-            return 'X2{:03d}{:03d}{:03d}'.format(x2cmd, byte1, byte2)
+            byte1 = (value >> 8) & 0xFF
+            byte2 = value & 0xFF
+            return "X2{:03d}{:03d}{:03d}".format(x2cmd, byte1, byte2)
 
         # Setting variables and thresholds absolute not implemented in LCN
         # firmware yet
-        raise ValueError('Wrong variable type.')
+        raise ValueError("Wrong variable type.")
 
     @staticmethod
     def var_reset(var, is2013=True):
@@ -511,12 +559,12 @@ class PckGenerator():
         var_id = lcn_defs.Var.to_var_id(var)
         if var_id != -1:
             if is2013:
-                pck = 'Z-{:03d}{:04d}'.format(var_id + 1, 4090)
+                pck = "Z-{:03d}{:04d}".format(var_id + 1, 4090)
             else:
                 if var_id == 0:
-                    pck = 'ZS30000'
+                    pck = "ZS30000"
                 else:
-                    raise ValueError('Wrong variable type.')
+                    raise ValueError("Wrong variable type.")
             return pck
 
         set_point_id = lcn_defs.Var.to_set_point_id(var)
@@ -525,10 +573,10 @@ class PckGenerator():
             byte1 = set_point_id << 6  # 01000000
             byte1 |= 0x20  # xx10xxxx 9set absolute)
             byte2 = 0
-            return 'X2{:03d}{:03d}{:03d}'.format(30, byte1, byte2)
+            return "X2{:03d}{:03d}{:03d}".format(30, byte1, byte2)
 
         # Reset for threshold not implemented in LCN firmware yet
-        raise ValueError('Wrong variable type.')
+        raise ValueError("Wrong variable type.")
 
     @staticmethod
     def var_rel(var, rel_var_ref, value, is2013=True):
@@ -549,22 +597,23 @@ class PckGenerator():
             if var_id == 0:
                 # Old command for variable 1 / T-var (compatible with all
                 # modules)
-                pck = 'Z{:s}{:d}'.format('A' if value >= 0 else 'S',
-                                         abs(value))
+                pck = "Z{:s}{:d}".format("A" if value >= 0 else "S", abs(value))
             else:
                 # New command for variable 1-12 (compatible with all modules,
                 # since LCN-PCHK 2.8)
-                pck = 'Z{:s}{:03d}{:d}'.format('+' if value >= 0 else '-',
-                                               var_id + 1, abs(value))
+                pck = "Z{:s}{:03d}{:d}".format(
+                    "+" if value >= 0 else "-", var_id + 1, abs(value)
+                )
             return pck
 
         set_point_id = lcn_defs.Var.to_set_point_id(var)
         if set_point_id != -1:
-            pck = 'RE{:s}S{:s}{:s}{:d}'.format(
-                'A' if set_point_id == 0 else 'B',
-                'A' if rel_var_ref == lcn_defs.RelVarRef.CURRENT else 'P',
-                '+' if value >= 0 else '-',
-                abs(value))
+            pck = "RE{:s}S{:s}{:s}{:d}".format(
+                "A" if set_point_id == 0 else "B",
+                "A" if rel_var_ref == lcn_defs.RelVarRef.CURRENT else "P",
+                "+" if value >= 0 else "-",
+                abs(value),
+            )
             return pck
 
         thrs_register_id = lcn_defs.Var.to_thrs_register_id(var)
@@ -572,26 +621,28 @@ class PckGenerator():
         if (thrs_register_id != -1) and (thrs_id != -1):
             if is2013:
                 # New command for registers 1-4 (since 170206, LCN-PCHK 2.8)
-                pck = 'SS{:s}{:04d}{:s}R{:d}{:d}'.format(
-                    'R' if rel_var_ref == lcn_defs.RelVarRef.CURRENT else 'E',
+                pck = "SS{:s}{:04d}{:s}R{:d}{:d}".format(
+                    "R" if rel_var_ref == lcn_defs.RelVarRef.CURRENT else "E",
                     abs(value),
-                    'A' if value >= 0 else 'S',
+                    "A" if value >= 0 else "S",
                     thrs_register_id + 1,
-                    thrs_id + 1)
+                    thrs_id + 1,
+                )
             elif thrs_register_id == 0:
                 # Old command for register 1 (before 170206)
-                pck = 'SS{:s}{:4d}{:s}{:s}{:s}{:s}{:s}{:s}'.format(
-                    'R' if rel_var_ref == lcn_defs.RelVarRef.CURRENT else 'E',
+                pck = "SS{:s}{:4d}{:s}{:s}{:s}{:s}{:s}{:s}".format(
+                    "R" if rel_var_ref == lcn_defs.RelVarRef.CURRENT else "E",
                     abs(value),
-                    'A' if value >= 0 else 'S',
-                    '1' if thrs_id == 0 else '0',
-                    '1' if thrs_id == 1 else '0',
-                    '1' if thrs_id == 2 else '0',
-                    '1' if thrs_id == 3 else '0',
-                    '1' if thrs_id == 4 else '0')
+                    "A" if value >= 0 else "S",
+                    "1" if thrs_id == 0 else "0",
+                    "1" if thrs_id == 1 else "0",
+                    "1" if thrs_id == 2 else "0",
+                    "1" if thrs_id == 3 else "0",
+                    "1" if thrs_id == 4 else "0",
+                )
             return pck
 
-        raise ValueError('Wrong variable type.')
+        raise ValueError("Wrong variable type.")
 
     @staticmethod
     def request_var_status(var, sw_age=0x170206):
@@ -605,38 +656,42 @@ class PckGenerator():
         if sw_age >= 0x170206:
             var_id = lcn_defs.Var.to_var_id(var)
             if var_id != -1:
-                return 'MWT{:03d}'.format(var_id + 1)
+                return "MWT{:03d}".format(var_id + 1)
 
             set_point_id = lcn_defs.Var.to_set_point_id(var)
             if set_point_id != -1:
-                return 'MWS{:03d}'.format(set_point_id + 1)
+                return "MWS{:03d}".format(set_point_id + 1)
 
             thrs_register_id = lcn_defs.Var.to_thrs_register_id(var)
             if thrs_register_id != -1:
                 # Whole register
-                return 'SE{:03d}'.format(thrs_register_id + 1)
+                return "SE{:03d}".format(thrs_register_id + 1)
 
             s0_id = lcn_defs.Var.to_s0_id(var)
             if s0_id != -1:
-                return 'MWC{:03d}'.format(s0_id + 1)
+                return "MWC{:03d}".format(s0_id + 1)
         else:
             if var == lcn_defs.Var.VAR1ORTVAR:
-                pck = 'MWV'
+                pck = "MWV"
             elif var == lcn_defs.Var.VAR2ORR1VAR:
-                pck = 'MWTA'
+                pck = "MWTA"
             elif var == lcn_defs.Var.VAR3ORR2VAR:
-                pck = 'MWTB'
+                pck = "MWTB"
             elif var == lcn_defs.Var.R1VARSETPOINT:
-                pck = 'MWSA'
+                pck = "MWSA"
             elif var == lcn_defs.Var.R2VARSETPOINT:
-                pck = 'MWSB'
-            elif var in [lcn_defs.Var.THRS1, lcn_defs.Var.THRS2,
-                         lcn_defs.Var.THRS3, lcn_defs.Var.THRS4,
-                         lcn_defs.Var.THRS5]:
-                pck = 'SL1'  # Whole register
+                pck = "MWSB"
+            elif var in [
+                lcn_defs.Var.THRS1,
+                lcn_defs.Var.THRS2,
+                lcn_defs.Var.THRS3,
+                lcn_defs.Var.THRS4,
+                lcn_defs.Var.THRS5,
+            ]:
+                pck = "SL1"  # Whole register
             return pck
 
-        raise ValueError('Wrong variable type.')
+        raise ValueError("Wrong variable type.")
 
     @staticmethod
     def request_leds_and_logic_ops():
@@ -645,7 +700,7 @@ class PckGenerator():
         :return: The PCK command (without address header) as text
         :rtype:  str
         """
-        return 'SMT'
+        return "SMT"
 
     @staticmethod
     def control_led(led_id, state):
@@ -657,8 +712,8 @@ class PckGenerator():
         :rtype:  str
         """
         if (led_id < 0) or (led_id > 11):
-            raise ValueError('Bad led_id.')
-        return 'LA{:03d}{:2}'.format(led_id + 1, state.value)
+            raise ValueError("Bad led_id.")
+        return "LA{:03d}{:2}".format(led_id + 1, state.value)
 
     @staticmethod
     def send_keys(cmds, keys):
@@ -673,8 +728,8 @@ class PckGenerator():
         :rtype:   str
         """
         if (len(cmds) != 4) or (len(keys) != 8):
-            raise ValueError('Wrong cmds length or wrong keys length.')
-        ret = 'TS'
+            raise ValueError("Wrong cmds length or wrong keys length.")
+        ret = "TS"
         for i, cmd in enumerate(cmds):
             if (cmd == lcn_defs.SendKeyCommand.DONTSEND) and (i == 3):
                 # By skipping table D (if it is not used), we use the old
@@ -684,7 +739,7 @@ class PckGenerator():
             ret += cmd.value
 
         for key in keys:
-            ret += '1' if key else '0'
+            ret += "1" if key else "0"
 
         return ret
 
@@ -701,35 +756,35 @@ class PckGenerator():
         :rtype:    str
         """
         if (table_id < 0) or (table_id > 3) or (len(keys) != 8):
-            raise ValueError('Bad table_id or keys.')
-        ret = 'TV'
+            raise ValueError("Bad table_id or keys.")
+        ret = "TV"
         try:
             ret += PckGenerator.TABLE_NAMES[table_id]
         except IndexError:
-            raise ValueError('Wrong table_id.')
+            raise ValueError("Wrong table_id.")
 
-        ret += '{:03d}'.format(time)
+        ret += "{:03d}".format(time)
         if time_unit == lcn_defs.TimeUnit.SECONDS:
             if (time < 1) or (time > 60):
-                raise ValueError('Wrong time.')
-            ret += 'S'
+                raise ValueError("Wrong time.")
+            ret += "S"
         elif time_unit == lcn_defs.TimeUnit.MINUTES:
             if (time < 1) or (time > 90):
-                raise ValueError('Wrong time.')
-            ret += 'M'
+                raise ValueError("Wrong time.")
+            ret += "M"
         elif time_unit == lcn_defs.TimeUnit.HOURS:
             if (time < 1) or (time > 50):
-                raise ValueError('Wrong time.')
-            ret += 'H'
+                raise ValueError("Wrong time.")
+            ret += "H"
         elif time_unit == lcn_defs.TimeUnit.DAYS:
             if (time < 1) or (time > 45):
-                raise ValueError('Wrong time.')
-            ret += 'D'
+                raise ValueError("Wrong time.")
+            ret += "D"
         else:
-            raise ValueError('Wrong time_unit.')
+            raise ValueError("Wrong time_unit.")
 
         for key in keys:
-            ret += '1' if key else '0'
+            ret += "1" if key else "0"
 
         return ret
 
@@ -742,7 +797,7 @@ class PckGenerator():
         :return:    The PCK command (without address header) as text
         :rtype:     str
         """
-        return 'STX'
+        return "STX"
 
     @staticmethod
     def lock_keys(table_id, states):
@@ -754,11 +809,11 @@ class PckGenerator():
         :rtype:    str
         """
         if (table_id < 0) or (table_id > 3) or (len(states) != 8):
-            raise ValueError('Bad table_id or states.')
+            raise ValueError("Bad table_id or states.")
         try:
-            ret = 'TX{:s}'.format(PckGenerator.TABLE_NAMES[table_id])
+            ret = "TX{:s}".format(PckGenerator.TABLE_NAMES[table_id])
         except IndexError:
-            raise ValueError('Wrong table_id.')
+            raise ValueError("Wrong table_id.")
 
         for state in states:
             ret += state.value
@@ -779,30 +834,30 @@ class PckGenerator():
         :rtype:    str
         """
         if len(keys) != 8:
-            raise ValueError('Wrong keys lenght.')
-        ret = 'TXZA{:03d}'.format(time)
+            raise ValueError("Wrong keys lenght.")
+        ret = "TXZA{:03d}".format(time)
 
         if time_unit == lcn_defs.TimeUnit.SECONDS:
             if (time < 1) or (time > 60):
-                raise ValueError('Wrong time.')
-            ret += 'S'
+                raise ValueError("Wrong time.")
+            ret += "S"
         elif time_unit == lcn_defs.TimeUnit.MINUTES:
             if (time < 1) or (time > 90):
-                raise ValueError('Wrong time.')
-            ret += 'M'
+                raise ValueError("Wrong time.")
+            ret += "M"
         elif time_unit == lcn_defs.TimeUnit.HOURS:
             if (time < 1) or (time > 50):
-                raise ValueError('Wrong time.')
-            ret += 'H'
+                raise ValueError("Wrong time.")
+            ret += "H"
         elif time_unit == lcn_defs.TimeUnit.DAYS:
             if (time < 1) or (time > 45):
-                raise ValueError('Wrong time.')
-            ret += 'D'
+                raise ValueError("Wrong time.")
+            ret += "D"
         else:
-            raise ValueError('Wrong time_unit.')
+            raise ValueError("Wrong time_unit.")
 
         for key in keys:
-            ret += '1' if key else '0'
+            ret += "1" if key else "0"
 
         return ret
 
@@ -822,11 +877,17 @@ class PckGenerator():
         :return:  The PCK command (without address header) as text
         :rtype:   str
         """
-        if (row_id < 0) or (row_id > 3) or (part_id < 0) or \
-           (part_id > 4) or (len(part) > 12):
-            raise ValueError('Wrong row_id, part_id or part length.')
-        return 'GTDT{:d}{:d}{:s}'.format(row_id + 1, part_id + 1,
-                                         part.decode(lcn_defs.LCN_ENCODING))
+        if (
+            (row_id < 0)
+            or (row_id > 3)
+            or (part_id < 0)
+            or (part_id > 4)
+            or (len(part) > 12)
+        ):
+            raise ValueError("Wrong row_id, part_id or part length.")
+        return "GTDT{:d}{:d}{:s}".format(
+            row_id + 1, part_id + 1, part.decode(lcn_defs.LCN_ENCODING)
+        )
 
     @staticmethod
     def lock_regulator(reg_id, state):
@@ -838,9 +899,8 @@ class PckGenerator():
         :rtype:   str
         """
         if (reg_id < 0) or (reg_id > 1):
-            raise ValueError('Wrong reg_id.')
-        return 'RE{:s}X{:s}'.format('A' if reg_id == 0 else 'B',
-                                    'S' if state else 'A')
+            raise ValueError("Wrong reg_id.")
+        return "RE{:s}X{:s}".format("A" if reg_id == 0 else "B", "S" if state else "A")
 
     @staticmethod
     def change_scene_register(register_id):
@@ -851,8 +911,8 @@ class PckGenerator():
         :rtype:   str
         """
         if (register_id < 0) or (register_id > 9):
-            raise ValueError('Wrong register_id.')
-        return 'SZW{:03d}'.format(register_id)
+            raise ValueError("Wrong register_id.")
+        return "SZW{:03d}".format(register_id)
 
     @staticmethod
     def activate_scene_output(scene_id, output_ports=(), ramp=None):
@@ -870,21 +930,23 @@ class PckGenerator():
         :rtype:   str
         """
         if (scene_id < 0) or (scene_id > 9):
-            raise ValueError('Wrong scene_id.')
+            raise ValueError("Wrong scene_id.")
         if not output_ports:
-            raise ValueError('output_port list is empty.')
+            raise ValueError("output_port list is empty.")
         output_mask = 0
         if lcn_defs.OutputPort.OUTPUT1 in output_ports:
             output_mask += 1
         if lcn_defs.OutputPort.OUTPUT2 in output_ports:
             output_mask += 2
-        if lcn_defs.OutputPort.OUTPUT3 in output_ports or\
-                lcn_defs.OutputPort.OUTPUT4 in output_ports:
+        if (
+            lcn_defs.OutputPort.OUTPUT3 in output_ports
+            or lcn_defs.OutputPort.OUTPUT4 in output_ports
+        ):
             output_mask += 4
         if ramp is None:
-            pck = 'SZA{:1d}{:03d}'.format(output_mask, scene_id)
+            pck = "SZA{:1d}{:03d}".format(output_mask, scene_id)
         else:
-            pck = 'SZA{:1d}{:03d}{:03d}'.format(output_mask, scene_id, ramp)
+            pck = "SZA{:1d}{:03d}{:03d}".format(output_mask, scene_id, ramp)
         return pck
 
     @staticmethod
@@ -898,10 +960,11 @@ class PckGenerator():
         :rtype:   str
         """
         if (scene_id < 0) or (scene_id > 9):
-            raise ValueError('Wrong scene_id.')
+            raise ValueError("Wrong scene_id.")
         if not relay_ports:
-            raise ValueError('relay_port list is empty.')
-        relays_mask = ['0'] * 8
+            raise ValueError("relay_port list is empty.")
+        relays_mask = ["0"] * 8
         for port in relay_ports:
-            relays_mask[port.value] = '1'
-        return 'SZA0{:03d}{:s}'.format(scene_id, ''.join(relays_mask))
+            relays_mask[port.value] = "1"
+        return "SZA0{:03d}{:s}".format(scene_id, "".join(relays_mask))
+
